# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`nvdarepo`](#nvdarepo): Installs NVIDIA package repositories.
* [`nvdarepo::cuda`](#nvdarepocuda): (Un-) Installs the NVIDIA CUDA repository.

### Defined types

* [`nvdarepo::cuda_module_files`](#nvdarepocuda_module_files): (Un-) Installs a module file for making specific CUDA versions
available on demand.
* [`nvdarepo::ordered_install`](#nvdarepoordered_install): (Un-) Installs packages in a specific order.
* [`nvdarepo::repo`](#nvdareporepo): (Un-) Installs a repository along with its GPG key.

## Classes

### <a name="nvdarepo"></a>`nvdarepo`

Installs all known NVIDIA repositories, which is at the moment only the CUDA
repository which provides CUDA tools and appropriate drivers. This extra class
is currently only there for future extensibility.

### <a name="nvdarepocuda"></a>`nvdarepo::cuda`

This class basically does nothing but instantiating the nvdarepo::repo
utility. Its main purpose is providing a class to which configuration data
can be assigned via Hiera.

#### Parameters

The following parameters are available in the `nvdarepo::cuda` class:

* [`base_url`](#base_url)
* [`version_field`](#version_field)
* [`repo_src_override`](#repo_src_override)
* [`distro_override`](#distro_override)
* [`repo_dir`](#repo_dir)
* [`repo_ext`](#repo_ext)
* [`repo_owner`](#repo_owner)
* [`repo_group`](#repo_group)
* [`key_id`](#key_id)
* [`key_file_name`](#key_file_name)
* [`key_src_override`](#key_src_override)
* [`key_dir`](#key_dir)
* [`key_prefix`](#key_prefix)
* [`ensure`](#ensure)
* [`disable_repos`](#disable_repos)

##### <a name="base_url"></a>`base_url`

Data type: `String`

The base URL where NVIDIA's repositories are located. If no
repo_src is provided, the module will construct the URL from
this base URL using the known way NVIDIA is organising their
server.

##### <a name="version_field"></a>`version_field`

Data type: `String`

This parameter determines which of the version facts is
used to automatically construct the URL of the
repository. The parameter defaults to 'major', ie the
major version of the distribution is used to construct
the repository source.

##### <a name="repo_src_override"></a>`repo_src_override`

Data type: `Variant[String, Boolean]`

Overrides the generated URL of the repository file
with the specified value. This parameter defaults
to false, which indicates that the repository URL
should be computed automatically.

Default value: ``false``

##### <a name="distro_override"></a>`distro_override`

Data type: `Variant[String, Boolean]`

Overrides the name in the distribution for the purpose
of generating the repository URL. This value is only
used when repo_src_override is not set. The parameter
defaults to false, which indicates that the OS name
from Puppet facts is used in lower case.

Default value: ``false``

##### <a name="repo_dir"></a>`repo_dir`

Data type: `String`

The directory where to install the repository file, ie
"/etc/yum.repos.d" for RedHat-based systems.

##### <a name="repo_ext"></a>`repo_ext`

Data type: `String`

The extension of the repository file, typically ".repo".

##### <a name="repo_owner"></a>`repo_owner`

Data type: `Variant[String, Integer]`

The name or UID of the owning user of the repository file.

##### <a name="repo_group"></a>`repo_group`

Data type: `Variant[String, Integer]`

The name or UID of the owning group of the repository file.

##### <a name="key_id"></a>`key_id`

Data type: `String`

The ID of the GPG key used by the repository.

##### <a name="key_file_name"></a>`key_file_name`

Data type: `String`

The name of the GPG key file to be installed.

##### <a name="key_src_override"></a>`key_src_override`

Data type: `Variant[String, Boolean]`

Override the full URL of from which the GPG key is
retrieved. Otherwise, the key is searched in the
repository directory.

Default value: ``false``

##### <a name="key_dir"></a>`key_dir`

Data type: `String`

The directory where the key should be installed. This is only
used on RedHat-based systems.

##### <a name="key_prefix"></a>`key_prefix`

Data type: `String`

An additional prefix string that is added before the
name of the key file. This is only used on RedHat-based
systems.

##### <a name="ensure"></a>`ensure`

Data type: `String`

Determines whether the repository should be present or absent.
This defaults to "present".

Default value: `present`

##### <a name="disable_repos"></a>`disable_repos`

Data type: `Array[String]`

Allows for specifying yum repositories to be disabled.
This is required to handle a conflict with
rpmfusion-nonfree on Fedora.

Default value: `[]`

## Defined types

### <a name="nvdarepocuda_module_files"></a>`nvdarepo::cuda_module_files`

This is a utility type that can be used by administrators to create module
files for installed CUDA versions. This allows end users to use the module
enviroment to switch between different versions of CUDA as necessary.

#### Parameters

The following parameters are available in the `nvdarepo::cuda_module_files` defined type:

* [`packages`](#packages)
* [`ensure`](#ensure)
* [`module_dir`](#module_dir)
* [`install_dir`](#install_dir)
* [`system_version`](#system_version)
* [`module_packages`](#module_packages)

##### <a name="packages"></a>`packages`

Data type: `Hash`

The hash from the ordered_install, which is used to filter
CUDA packages and create the module files for them.

##### <a name="ensure"></a>`ensure`

Data type: `String`

Indicates whether the module file should be written or
removed. This defaults to 'present'.

Default value: `present`

##### <a name="module_dir"></a>`module_dir`

Data type: `String`

The directory receiving the module file. This parameter
defaults to '/etc/modulefiles'.

Default value: `'/etc/modulefiles'`

##### <a name="install_dir"></a>`install_dir`

Data type: `String`

The directory where CUDA is assumed to be installed. If
a specific version is selected, this version is suffixed
to this path, wherefore it should not be terminated with
a directory separator. This parameter defaults to
'/usr/local/cuda'.

Default value: `'/usr/local/cuda'`

##### <a name="system_version"></a>`system_version`

Data type: `String`

The version string used for the default current version
of CUDA. This parameter defaults to 'system'.

Default value: `'system'`

##### <a name="module_packages"></a>`module_packages`

Data type: `Array[String]`



Default value: `[ 'environment-modules' ]`

### <a name="nvdarepoordered_install"></a>`nvdarepo::ordered_install`

Installing CUDA on RHEL systems requires packages being installed in a
specific order to use the DKMS driver module. This utility class enables
you to do that by specifying aliases for the packages that define the
order by means of their lexical order. The keys in the $packages hash
given to the module determines this order. A dependency relationship
between these keys will be established by this module. In order to
specify this order in Hiera, it is best using keys starting with
numbers like it is common in conf.d directories.

#### Parameters

The following parameters are available in the `nvdarepo::ordered_install` defined type:

* [`packages`](#packages)

##### <a name="packages"></a>`packages`

Data type: `Hash`

The $packages parameter is a hash specifying the packages
to be installed. The keys of that hash determine the
order in which the installation happens. The hash should
at least hold the attributes "name" with the actual name
of the package and "ensure" with the installation instruction.
All of the per-package attributes are passed on to the
installation, i.e. you can use every parameter that is
acceptable for the Package resource.

### <a name="nvdareporepo"></a>`nvdarepo::repo`

This is a utility type that is used by the nvdarepo class. It is not intended
for direct use by end users. One main feature of the type is that it can
compute the repository location based on the current layou of NVIDIA's server
from the OS information provided by Puppet.

#### Parameters

The following parameters are available in the `nvdarepo::repo` defined type:

* [`base_url`](#base_url)
* [`version_field`](#version_field)
* [`repo_src_override`](#repo_src_override)
* [`distro_override`](#distro_override)
* [`repo_dir`](#repo_dir)
* [`repo_ext`](#repo_ext)
* [`repo_owner`](#repo_owner)
* [`repo_group`](#repo_group)
* [`key_id`](#key_id)
* [`key_file_name`](#key_file_name)
* [`key_src_override`](#key_src_override)
* [`key_dir`](#key_dir)
* [`key_prefix`](#key_prefix)
* [`ensure`](#ensure)
* [`disable_repos`](#disable_repos)

##### <a name="base_url"></a>`base_url`

Data type: `String`

The base URL where NVIDIA's repositories are located. If no
repo_src is provided, the module will construct the URL from
this base URL using the known way NVIDIA is organising their
server.

##### <a name="version_field"></a>`version_field`

Data type: `String`

This parameter determines which of the version facts is
used to automatically construct the URL of the
repository. The parameter defaults to 'major', ie the
major version of the distribution is used to construct
the repository source.

##### <a name="repo_src_override"></a>`repo_src_override`

Data type: `Variant[String, Boolean]`

Overrides the generated URL of the repository file
with the specified value.

Default value: ``false``

##### <a name="distro_override"></a>`distro_override`

Data type: `Variant[String, Boolean]`

Overrides the name in the distribution for the purpose
of generating the repository URL. This value is only
used when repo_src_override is not set.

Default value: ``false``

##### <a name="repo_dir"></a>`repo_dir`

Data type: `String`

The directory where to install the repository file, ie
"/etc/yum.repos.d" for RedHat-based systems.

##### <a name="repo_ext"></a>`repo_ext`

Data type: `String`

The extension of the repository file, typically ".repo".

##### <a name="repo_owner"></a>`repo_owner`

Data type: `Variant[String, Integer]`

The name or UID of the owning user of the repository file.

##### <a name="repo_group"></a>`repo_group`

Data type: `Variant[String, Integer]`

The name or UID of the owning group of the repository file.

##### <a name="key_id"></a>`key_id`

Data type: `String`

The ID of the GPG key used by the repository.

##### <a name="key_file_name"></a>`key_file_name`

Data type: `String`

The name of the GPG key file to be installed.

##### <a name="key_src_override"></a>`key_src_override`

Data type: `Variant[String, Boolean]`

Override the full URL of from which the GPG key is
retrieved. Otherwise, the key is searched in the
repository directory.

Default value: ``false``

##### <a name="key_dir"></a>`key_dir`

Data type: `String`

The directory where the key should be installed. This is only
used on RedHat-based systems.

##### <a name="key_prefix"></a>`key_prefix`

Data type: `String`

An additional prefix string that is added before the
name of the key file. This is only used on RedHat-based
systems and should be something like "RPM-GPG-KEY-".

##### <a name="ensure"></a>`ensure`

Data type: `String`

Determines whether the repository should be present or absent.
This defaults to "present".

Default value: `present`

##### <a name="disable_repos"></a>`disable_repos`

Data type: `Array[String]`

Allows for specifying yum repositories to be disabled.
This is required to handle a conflict with
rpmfusion-nonfree on Fedora.

Default value: `[]`

